@@ -85,7 +85,9 @@ pub fn apply_source_map<G: SourceMapGetter>(
     .map(|cause| Box::new(apply_source_map(&*cause, getter)));
 
   JsError {
+    name: js_error.name.clone(),
     message: js_error.message.clone(),
+    exception_message: js_error.exception_message.clone(),
     cause,
     source_line,
     script_resource_name,
@@ -243,7 +245,9 @@ mod tests {
   #[test]
   fn apply_source_map_line() {
     let e = JsError {
-      message: "TypeError: baz".to_string(),
+      name: Some("TypeError".to_string()),
+      message: Some("baz".to_string()),
+      exception_message: "TypeError: baz".to_string(),
       cause: None,
       source_line: Some("foo".to_string()),
       script_resource_name: Some("foo_bar.ts".to_string()),
