@@ -97,6 +97,18 @@ itest!(markdown_windows {
   output: "test/markdown_windows.out",
 });
 
+itest!(markdown_full_block_names {
+  args: "test --doc --allow-all test/markdown_full_block_names.md",
+  exit_code: 1,
+  output: "test/markdown_full_block_names.out",
+});
+
+itest!(markdown_ignore_html_comment {
+  args: "test --doc --allow-all test/markdown_with_comment.md",
+  exit_code: 1,
+  output: "test/markdown_with_comment.out",
+});
+
 itest!(text {
   args: "test --doc --allow-all test/text.md",
   exit_code: 0,
@@ -146,7 +158,7 @@ itest!(allow_none {
 });
 
 itest!(ops_sanitizer_unstable {
-  args: "test --unstable test/ops_sanitizer_unstable.ts",
+  args: "test --unstable --trace-ops test/ops_sanitizer_unstable.ts",
   exit_code: 1,
   output: "test/ops_sanitizer_unstable.out",
 });
@@ -157,11 +169,23 @@ itest!(ops_sanitizer_timeout_failure {
 });
 
 itest!(ops_sanitizer_multiple_timeout_tests {
-  args: "test test/ops_sanitizer_multiple_timeout_tests.ts",
+  args: "test --trace-ops test/ops_sanitizer_multiple_timeout_tests.ts",
   exit_code: 1,
   output: "test/ops_sanitizer_multiple_timeout_tests.out",
 });
 
+itest!(ops_sanitizer_multiple_timeout_tests_no_trace {
+  args: "test test/ops_sanitizer_multiple_timeout_tests.ts",
+  exit_code: 1,
+  output: "test/ops_sanitizer_multiple_timeout_tests_no_trace.out",
+});
+
+itest!(ops_sanitizer_missing_details {
+  args: "test --allow-write --allow-read test/ops_sanitizer_missing_details.ts",
+  exit_code: 1,
+  output: "test/ops_sanitizer_missing_details.out",
+});
+
 itest!(ops_sanitizer_nexttick {
   args: "test test/ops_sanitizer_nexttick.ts",
   output: "test/ops_sanitizer_nexttick.out",
